@@ -10,6 +10,7 @@ my $r;
 ok $r = $es->search(
     query  => { match_all => {} },
     sort   => ['num'],
+    fields => ['_id'],
     scroll => '5m',
     size   => 2
     ),
@@ -20,18 +21,19 @@ ok $scroll_id, ' - has scroll ID';
 is $r->{hits}{hits}[0]{_id}, 1, ' - first hit is ID 1';
 is $r->{hits}{hits}[1]{_id}, 2, ' - second hit is ID 2';
 
-TODO: {
-    local $TODO = "Sorting when scrolling is broken on server";
+for my $tranche ( 1 .. 14 ) {
     ok $r = $es->scroll( scroll_id => $scroll_id, scroll => '5m' ),
-        ' - next tranche';
-    is $r->{hits}{hits}[0]{_id}, 3, ' - first hit is ID 3';
-    is $r->{hits}{hits}[1]{_id}, 4, ' - second hit is ID 4';
+        " - tranche $tranche";
+    my $first  = 1 + 2 * $tranche;
+    my $second = $first + 1;
+    if ( $tranche == 14 ) {
+        $first  = 30;
+        $second = undef;
+    }
+    is $r->{hits}{hits}[0]{_id}, $first, " - first hit is ID $first";
+    is $r->{hits}{hits}[1]{_id}, $second,
+        " - first hit is ID " . ( $second || 'undef' );
 
-    $scroll_id = $r->{_scroll_id};
-
-    ok $r = $es->scroll( scroll_id => $scroll_id ), ' - next tranche';
-    is $r->{hits}{hits}[0]{_id}, 3, ' - first hit is ID 5';
-    is $r->{hits}{hits}[1]{_id}, 4, ' - second hit is ID 6';
 }
 
 1;
